@@ -7,16 +7,17 @@ import sys
 
 from .guard import prevent_distribution
 from .function import SlurmFunction
+from .function_map import set_entry_point
+import json
 
 
 def main():
 
     prevent_distribution()  # make sure, the code on the node does not distribute itself.
     batch_file = sys.argv[1]  # the file with the code (function definition)
-    funcid = sys.argv[2]  # the function to be called
-    args = sys.argv[3]  # the arguments to call the function with
+    instructions = sys.argv[2]
     # Load the code
-    SlurmFunction._entry_point = batch_file
+    set_entry_point(batch_file)
     with open(batch_file, "r") as f:
         code = "".join(f.readlines())
 
@@ -27,8 +28,11 @@ def main():
         glob = dict(globals())
         glob["__file__"] = batch_file
         exec(code, glob)
-    # Execute the function
-    SlurmFunction.call(funcid, args)
+    # Execute the functions
+    argd = json.loads(instructions)
+    assert isinstance(argd, list), "Should be a list of dicts"
+    for fc in argd:
+        SlurmFunction.call(fc["func_id"], *fc.get("args", []), **fc.get("kwargs", {}))
 
 
 if __name__ == "__main__":
